@@ -7,13 +7,14 @@ Created on Thu Apr 23 10:03:01 2020
 """
 
 import re as reg
-from sys import exc_info
 from copy import deepcopy
+from sys import exc_info
+
 import pandas as pd
 
 pd.options.mode.chained_assignment = None
 
-COL_MED = ['date_published', 'title', 'text', "url", 'source']
+COL_MED = ["date_published", "title", "text", "url", "source"]
 ERR_SYS = "system error: "
 
 
@@ -32,13 +33,12 @@ def create_regex(list_terms):
         DESCRIPTION. list without @name
 
     """
-    pattern = r'\b@*' + r'\b|\b@*'.join(list_terms) + r'\b'
+    pattern = r"\b@*" + r"\b|\b@*".join(list_terms) + r"\b"
     pat = reg.compile(pattern)
     return pat
 
 
-class MediaPres():
-
+class MediaPres:
     def __init__(self, dfm, df_count, brand, auto_n=True):
         """Digital media presence
         This function calculates digital media presence, comparing it with the
@@ -81,7 +81,7 @@ class MediaPres():
         df_all = self.df_m
         df_c = self.df_count
         auto_n = self.auto_n
-        df_empty_c = pd.DataFrame(columns=['media', 'mentions'])
+        df_empty_c = pd.DataFrame(columns=["media", "mentions"])
         method_name = "count_pres"
 
         try:
@@ -92,10 +92,14 @@ class MediaPres():
             df_w.text = df_w.text.apply(lambda x: x.lower())
             df_m = deepcopy(df_w)
 
-            for idd, row in df_c.set_index('nombre').iterrows():
+            for idd, row in df_c.set_index("nombre").iterrows():
                 if idd:
-                    account_terms_regex = create_regex([t.strip() for t in row.terminos.split(',')])
-                    df_m[f'{idd}'] = df_m['text'].str.contains(account_terms_regex, regex=True)
+                    account_terms_regex = create_regex(
+                        [t.strip() for t in row.terminos.split(",")]
+                    )
+                    df_m[f"{idd}"] = df_m["text"].str.contains(
+                        account_terms_regex, regex=True
+                    )
 
             df_m["auto"] = 0
 
@@ -112,7 +116,8 @@ class MediaPres():
                 df_m2 = df_m
 
             df_med_c = df_m2.drop(
-                columns=['date_published', 'title', 'text', "auto"]).groupby('source')
+                columns=["date_published", "title", "text", "auto"]
+            ).groupby("source")
             df_med_c = df_med_c.sum().T
 
             df_med_c = pd.DataFrame(df_med_c.T.sum())
@@ -124,21 +129,21 @@ class MediaPres():
         except KeyError as e_1:
             print(e_1)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
 
             df_med_c = df_empty_c
 
         except AttributeError as e_2:
             print(e_2)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
 
             df_med_c = df_empty_c
 
         except Exception as e_3:
             print(e_3)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
 
             df_med_c = df_empty_c
 
@@ -160,7 +165,9 @@ class MediaPres():
         df_c = self.df_count
         brand = self.brand
         auto_n = self.auto_n
-        df_empty_url = pd.DataFrame(columns=['date_published', 'source', 'title', 'url'])
+        df_empty_url = pd.DataFrame(
+            columns=["date_published", "source", "title", "url"]
+        )
         method_name = "url_pres"
 
         try:
@@ -172,10 +179,14 @@ class MediaPres():
             df_w.text = df_w.text.apply(lambda x: x.lower())
 
             df_m = deepcopy(df_w)
-            for idd, row in df_c.set_index('nombre').iterrows():
+            for idd, row in df_c.set_index("nombre").iterrows():
                 if idd:
-                    account_terms_regex = create_regex([t.strip() for t in row.terminos.split(',')])
-                    df_m[f'{idd}'] = df_m['text'].str.contains(account_terms_regex, regex=True)
+                    account_terms_regex = create_regex(
+                        [t.strip() for t in row.terminos.split(",")]
+                    )
+                    df_m[f"{idd}"] = df_m["text"].str.contains(
+                        account_terms_regex, regex=True
+                    )
 
             df_m["auto"] = 0
 
@@ -199,21 +210,21 @@ class MediaPres():
         except KeyError as e_1:
             print(e_1)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
 
             df_med_url = df_empty_url
 
         except AttributeError as e_2:
             print(e_2)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
 
             df_med_url = df_empty_url
 
         except Exception as e_3:
             print(e_3)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
 
             df_med_url = df_empty_url
 
